@@ -1,4 +1,5 @@
 import requests, urllib.parse, urllib3, json
+from urllib3 import encode_multipart_formdata
 
 
 class HttpHelper:
@@ -28,3 +29,10 @@ class HttpHelper:
             url_data = urllib.parse.urlencode(url_param)
             url = url + "?" + url_data
         return requests.post(url, headers=headers, files=stream)
+
+    def httpPostFile(self, header, url, file_path):
+        data = {}
+        data['file'] = (file_path.split("/")[-1], open(file_path, 'rb').read())  # 名称，读文件
+        encode_data = encode_multipart_formdata(data)
+        header['Content-Type'] = encode_data[1]
+        return requests.post(url, headers=header, data=encode_data[0])
